From f572e2bb7be34ef3b50cce7ef93dbccb490f148b Mon Sep 17 00:00:00 2001
From: Jerry Han <jerry.han.hq@gmail.com>
Date: Mon, 16 Sep 2019 17:26:32 +0800
Subject: [PATCH 9/9] [v10,9/9] drm/panel: Add Boe Himax8279d MIPI-DSI LCD
 panel

Support Boe Himax8279d 8.0" 1200x1920 TFT LCD panel, it is a MIPI DSI
panel.

V9:
- Adjust init code, make the format more concise
- kill off default_off_cmds (Emil)
- use mipi_dsi_dcs_set_display_{on,off} in their enable/disable
    callbacks. (Emil)
- Adjusting the delay function (Emil)

V8:
- modify PARENTHESIS_ALIGNMENT format (Sam)
- use gpios are required API replace optional gpio API (Emil)

V7:
- Modify communication address

V6:
- Add the information of the reviewer
- Remove unnecessary delays, The udelay_range code gracefully returns
    without hitting the scheduler on a delay of 0. (Derek)
- Merge the same data structures, like display_mode and off_cmds (Derek)
- Optimize the processing of results returned by
    devm_gpiod_get_optional (Derek)

V5:
- Add the information of the reviewer (Sam)
- Delete unnecessary header files #include <linux/fb.h> (Sam)
- The config DRM_PANEL_BOE_HIMAX8279D appears twice. Drop one of them (Sam)
- ADD static, set_gpios function is not used outside this module (Sam)

V4:
- Frefix all function maes with boe_ (Sam)
- Fsed "enable_gpio" replace "reset_gpio", Make it look clearer (Sam)
- Sort include lines alphabetically (Sam)
- Fixed entries in the makefile must be sorted alphabetically (Sam)
- Add send_mipi_cmds function to avoid duplicating the code (Sam)
- Add the necessary delay(reset_delay_t5) between reset and sending
    the initialization command (Rock wang)

V3:
- Remove unnecessary delays in sending initialization commands (Jitao Shi)

V2:
- Use SPDX identifier (Sam)
- Use necessary header files replace drmP.h (Sam)
- Delete unnecessary header files #include <linux/err.h> (Sam)
- Specifies a GPIOs array to control the reset timing,
    instead of reading "dsi-reset-sequence" data from DTS (Sam)
- Delete backlight_disable() function when already disabled (Sam)
- Use devm_of_find_backlight() replace of_find_backlight_by_node() (Sam)
- Move the necessary data in the DTS to the current file,
    like porch, display_mode and Init code etc. (Sam)
- Add compatible device "boe,himax8279d10p" (Sam)

V1:
- Support Boe Himax8279d 8.0" 1200x1920 TFT LCD panel, it is a MIPI DSI
    panel.

Signed-off-by: Jerry Han <jerry.han.hq@gmail.com>
Reviewed-by: Sam Ravnborg <sam@ravnborg.org>
Reviewed-by: Derek Basehore <dbasehore@chromium.org>
Reviewed-by: Emil Velikov <emil.l.velikov@gmail.com>
Cc: Jitao Shi <jitao.shi@mediatek.com>
Cc: Rock wang <rock_wang@himax.com.cn>
---
 drivers/gpu/drm/panel/panel-boe-himax8279d.c | 1235 +++++++++---------
 1 file changed, 588 insertions(+), 647 deletions(-)

diff --git a/drivers/gpu/drm/panel/panel-boe-himax8279d.c b/drivers/gpu/drm/panel/panel-boe-himax8279d.c
index 7790f76d3ce7..6265bf975365 100644
--- a/drivers/gpu/drm/panel/panel-boe-himax8279d.c
+++ b/drivers/gpu/drm/panel/panel-boe-himax8279d.c
@@ -39,17 +39,10 @@ struct panel_desc {
 	unsigned int width_mm;
 	unsigned int height_mm;
 
-	unsigned int delay_t1;
-	unsigned int reset_delay_t2;
-	unsigned int reset_delay_t3;
-	unsigned int reset_delay_t4;
-	unsigned int reset_delay_t5;
-
 	unsigned long mode_flags;
 	enum mipi_dsi_pixel_format format;
 	unsigned int lanes;
 	const struct panel_cmd *on_cmds;
-	const struct panel_cmd *off_cmds;
 };
 
 struct panel_info {
@@ -90,18 +83,11 @@ static int send_mipi_cmds(struct drm_panel *panel, const struct panel_cmd *cmds)
 	for (i = 0; cmds[i].len != 0; i++) {
 		const struct panel_cmd *cmd = &cmds[i];
 
-		if (cmd->len == 2)
-			err = mipi_dsi_dcs_write(pinfo->link, cmd->data[1],
-						 NULL, 0);
-		else
-			err = mipi_dsi_dcs_write(pinfo->link, cmd->data[1],
-						 cmd->data + 2,
-						 cmd->len - 2);
+		err = mipi_dsi_dcs_write(pinfo->link, cmd->data[0],
+					 cmd->data + 1, 1);
 
 		if (err < 0)
 			return err;
-
-		usleep_range((cmd->data[0]) * 1000, (1 + cmd->data[0]) * 1000);
 	}
 
 	return 0;
@@ -126,14 +112,23 @@ static int boe_panel_unprepare(struct drm_panel *panel)
 	if (!pinfo->prepared)
 		return 0;
 
-	/* send off code */
-	err = send_mipi_cmds(panel, pinfo->desc->off_cmds);
+	err = mipi_dsi_dcs_set_display_off(pinfo->link);
+	if (err < 0) {
+		DRM_DEV_ERROR(panel->dev, "failed to set display off: %d\n",
+			      err);
+		goto poweroff;
+	}
+
+	err = mipi_dsi_dcs_enter_sleep_mode(pinfo->link);
 	if (err < 0) {
-		DRM_DEV_ERROR(panel->dev, "failed to send DCS Off Code: %d\n",
+		DRM_DEV_ERROR(panel->dev, "failed to enter sleep mode: %d\n",
 			      err);
 		goto poweroff;
 	}
 
+	/* sleep_mode_delay: 1ms - 2ms */
+	usleep_range(1000, 2000);
+
 	set_gpios(pinfo, 0);
 
 	pinfo->prepared = false;
@@ -148,28 +143,31 @@ static int boe_panel_unprepare(struct drm_panel *panel)
 static int boe_panel_prepare(struct drm_panel *panel)
 {
 	struct panel_info *pinfo = to_panel_info(panel);
-	const struct panel_desc *desc = pinfo->desc;
 	int err;
 
 	if (pinfo->prepared)
 		return 0;
 
 	gpiod_set_value(pinfo->pp18_gpio, 1);
-	/* T1 (> 5ms) */
-	usleep_range(desc->delay_t1, 1000 + desc->delay_t1);
+	/* T1: 5ms - 6ms */
+	usleep_range(5000, 6000);
 	gpiod_set_value(pinfo->pp33_gpio, 1);
 
 	/* reset sequence */
-	usleep_range(desc->reset_delay_t2, 1000 + desc->reset_delay_t2);
-
+	/* T2: 14ms - 15ms */
+	usleep_range(14000, 15000);
 	gpiod_set_value(pinfo->enable_gpio, 1);
-	usleep_range(desc->reset_delay_t3, 1000 + desc->reset_delay_t3);
+
+	/* T3: 1ms - 2ms */
+	usleep_range(1000, 2000);
 	gpiod_set_value(pinfo->enable_gpio, 0);
 
-	usleep_range(desc->reset_delay_t4, 1000 + desc->reset_delay_t4);
+	/* T4: 1ms - 2ms */
+	usleep_range(1000, 2000);
 	gpiod_set_value(pinfo->enable_gpio, 1);
 
-	usleep_range(desc->reset_delay_t5, 1000 + desc->reset_delay_t5);
+	/* T5: 5ms - 6ms */
+	usleep_range(5000, 6000);
 
 	/* send init code */
 	err = send_mipi_cmds(panel, pinfo->desc->on_cmds);
@@ -179,6 +177,26 @@ static int boe_panel_prepare(struct drm_panel *panel)
 		goto poweroff;
 	}
 
+	err = mipi_dsi_dcs_exit_sleep_mode(pinfo->link);
+	if (err < 0) {
+		DRM_DEV_ERROR(panel->dev, "failed to exit sleep mode: %d\n",
+			      err);
+		goto poweroff;
+	}
+
+	/* T6: 120ms - 121ms */
+	usleep_range(120000, 121000);
+
+	err = mipi_dsi_dcs_set_display_on(pinfo->link);
+	if (err < 0) {
+		DRM_DEV_ERROR(panel->dev, "failed to set display on: %d\n",
+			      err);
+		goto poweroff;
+	}
+
+	/* T7: 20ms - 21ms */
+	usleep_range(20000, 21000);
+
 	pinfo->prepared = true;
 
 	return 0;
@@ -253,317 +271,268 @@ static const struct drm_display_mode default_display_mode = {
 	.vrefresh = 60,
 };
 
-static const struct panel_cmd default_off_cmds[] = {
-	_INIT_CMD(0x00, 0x28),
-	_INIT_CMD(0x01, 0x10),
-
-	{},
-};
-
 /* 8 inch */
 static const struct panel_cmd boe_himax8279d8p_on_cmds[] = {
-	_INIT_CMD(0x22, 0x10),
-	_INIT_CMD(0x00, 0xB0, 0x05),
-	_INIT_CMD(0x00, 0xB1, 0xE5),
-	_INIT_CMD(0x00, 0xB3, 0x52),
-	_INIT_CMD(0x00, 0xB0, 0x00),
-	_INIT_CMD(0x00, 0xB3, 0x88),
-	_INIT_CMD(0x00, 0xB0, 0x04),
-	_INIT_CMD(0x00, 0xB8, 0x00),
-	_INIT_CMD(0x00, 0xB0, 0x00),
-	_INIT_CMD(0x00, 0xB2, 0x50),
-	_INIT_CMD(0x00, 0xB6, 0x03),
-	_INIT_CMD(0x00, 0xBA, 0x8B),
-	_INIT_CMD(0x00, 0xBF, 0x15),
-	_INIT_CMD(0x00, 0xC0, 0x0F),
-	_INIT_CMD(0x00, 0xC2, 0x0C),
-	_INIT_CMD(0x00, 0xC3, 0x02),
-	_INIT_CMD(0x00, 0xC4, 0x0C),
-	_INIT_CMD(0x00, 0xC5, 0x02),
-	_INIT_CMD(0x00, 0xB0, 0x01),
-	_INIT_CMD(0x00, 0xE0, 0x26),
-	_INIT_CMD(0x00, 0xE1, 0x26),
-	_INIT_CMD(0x00, 0xDC, 0x00),
-	_INIT_CMD(0x00, 0xDD, 0x00),
-	_INIT_CMD(0x00, 0xCC, 0x26),
-	_INIT_CMD(0x00, 0xCD, 0x26),
-	_INIT_CMD(0x00, 0xC8, 0x00),
-	_INIT_CMD(0x00, 0xC9, 0x00),
-	_INIT_CMD(0x00, 0xD2, 0x04),
-	_INIT_CMD(0x00, 0xD3, 0x04),
-	_INIT_CMD(0x00, 0xE6, 0x03),
-	_INIT_CMD(0x00, 0xE7, 0x03),
-	_INIT_CMD(0x00, 0xC4, 0x08),
-	_INIT_CMD(0x00, 0xC5, 0x08),
-	_INIT_CMD(0x00, 0xD8, 0x07),
-	_INIT_CMD(0x00, 0xD9, 0x07),
-	_INIT_CMD(0x00, 0xC2, 0x06),
-	_INIT_CMD(0x00, 0xC3, 0x06),
-	_INIT_CMD(0x00, 0xD6, 0x05),
-	_INIT_CMD(0x00, 0xD7, 0x05),
-	_INIT_CMD(0x00, 0xC0, 0x0C),
-	_INIT_CMD(0x00, 0xC1, 0x0C),
-	_INIT_CMD(0x00, 0xD4, 0x0B),
-	_INIT_CMD(0x00, 0xD5, 0x0B),
-	_INIT_CMD(0x00, 0xCA, 0x0A),
-	_INIT_CMD(0x00, 0xCB, 0x0A),
-	_INIT_CMD(0x00, 0xDE, 0x09),
-	_INIT_CMD(0x00, 0xDF, 0x09),
-	_INIT_CMD(0x00, 0xC6, 0x26),
-	_INIT_CMD(0x00, 0xC7, 0x26),
-	_INIT_CMD(0x00, 0xCE, 0x00),
-	_INIT_CMD(0x00, 0xCF, 0x00),
-	_INIT_CMD(0x00, 0xDA, 0x26),
-	_INIT_CMD(0x00, 0xDB, 0x26),
-	_INIT_CMD(0x00, 0xE2, 0x00),
-	_INIT_CMD(0x00, 0xE3, 0x00),
-	_INIT_CMD(0x00, 0xB0, 0x02),
-	_INIT_CMD(0x00, 0xC0, 0x00),
-	_INIT_CMD(0x00, 0xC1, 0x07),
-	_INIT_CMD(0x00, 0xC2, 0x0D),
-	_INIT_CMD(0x00, 0xC3, 0x18),
-	_INIT_CMD(0x00, 0xC4, 0x27),
-	_INIT_CMD(0x00, 0xC5, 0x28),
-	_INIT_CMD(0x00, 0xC6, 0x30),
-	_INIT_CMD(0x00, 0xC7, 0x2E),
-	_INIT_CMD(0x00, 0xC8, 0x2F),
-	_INIT_CMD(0x00, 0xC9, 0x1A),
-	_INIT_CMD(0x00, 0xCA, 0x20),
-	_INIT_CMD(0x00, 0xCB, 0x29),
-	_INIT_CMD(0x00, 0xCC, 0x26),
-	_INIT_CMD(0x00, 0xCD, 0x32),
-	_INIT_CMD(0x00, 0xCE, 0x33),
-	_INIT_CMD(0x00, 0xCF, 0x31),
-	_INIT_CMD(0x00, 0xD0, 0x06),
-	_INIT_CMD(0x00, 0xD2, 0x00),
-	_INIT_CMD(0x00, 0xD3, 0x07),
-	_INIT_CMD(0x00, 0xD4, 0x12),
-	_INIT_CMD(0x00, 0xD5, 0x26),
-	_INIT_CMD(0x00, 0xD6, 0x3D),
-	_INIT_CMD(0x00, 0xD7, 0x3F),
-	_INIT_CMD(0x00, 0xD8, 0x3F),
-	_INIT_CMD(0x00, 0xD9, 0x3F),
-	_INIT_CMD(0x00, 0xDA, 0x3F),
-	_INIT_CMD(0x00, 0xDB, 0x3F),
-	_INIT_CMD(0x00, 0xDC, 0x3F),
-	_INIT_CMD(0x00, 0xDD, 0x3F),
-	_INIT_CMD(0x00, 0xDE, 0x3F),
-	_INIT_CMD(0x00, 0xDF, 0x3A),
-	_INIT_CMD(0x00, 0xE0, 0x37),
-	_INIT_CMD(0x00, 0xE1, 0x35),
-	_INIT_CMD(0x00, 0xE2, 0x07),
-	_INIT_CMD(0x00, 0xB0, 0x03),
-	_INIT_CMD(0x00, 0xC8, 0x0B),
-	_INIT_CMD(0x00, 0xC9, 0x07),
-	_INIT_CMD(0x00, 0xC3, 0x00),
-	_INIT_CMD(0x00, 0xE7, 0x00),
-	_INIT_CMD(0x00, 0xC5, 0x2A),
-	_INIT_CMD(0x00, 0xDE, 0x2A),
-	_INIT_CMD(0x00, 0xCA, 0x43),
-	_INIT_CMD(0x00, 0xC9, 0x07),
-	_INIT_CMD(0x00, 0xE4, 0xC0),
-	_INIT_CMD(0x00, 0xE5, 0x0D),
-	_INIT_CMD(0x00, 0xCB, 0x00),
-	_INIT_CMD(0x00, 0xB0, 0x06),
-	_INIT_CMD(0x00, 0xB8, 0xA5),
-	_INIT_CMD(0x00, 0xC0, 0xA5),
-	_INIT_CMD(0x00, 0xC7, 0x0F),
-	_INIT_CMD(0x00, 0xD5, 0x32),
-	_INIT_CMD(0x00, 0xB8, 0x00),
-	_INIT_CMD(0x00, 0xC0, 0x00),
-	_INIT_CMD(0x00, 0xBC, 0x00),
-	_INIT_CMD(0x00, 0xB0, 0x07),
-	_INIT_CMD(0x00, 0xB1, 0x00),
-	_INIT_CMD(0x00, 0xB2, 0x09),
-	_INIT_CMD(0x00, 0xB3, 0x19),
-	_INIT_CMD(0x00, 0xB4, 0x2F),
-	_INIT_CMD(0x00, 0xB5, 0x44),
-	_INIT_CMD(0x00, 0xB6, 0x52),
-	_INIT_CMD(0x00, 0xB7, 0x6A),
-	_INIT_CMD(0x00, 0xB8, 0x8A),
-	_INIT_CMD(0x00, 0xB9, 0xCA),
-	_INIT_CMD(0x00, 0xBA, 0x0C),
-	_INIT_CMD(0x05, 0xBB, 0x87),
-	_INIT_CMD(0x00, 0xBC, 0x06),
-	_INIT_CMD(0x00, 0xBD, 0x0A),
-	_INIT_CMD(0x00, 0xBE, 0x9B),
-	_INIT_CMD(0x00, 0xBF, 0x0C),
-	_INIT_CMD(0x00, 0xC0, 0x3D),
-	_INIT_CMD(0x00, 0xC1, 0x71),
-	_INIT_CMD(0x00, 0xC2, 0x90),
-	_INIT_CMD(0x00, 0xC3, 0xA0),
-	_INIT_CMD(0x00, 0xC4, 0xA8),
-	_INIT_CMD(0x00, 0xC5, 0xB1),
-	_INIT_CMD(0x00, 0xC6, 0xBB),
-	_INIT_CMD(0x00, 0xC7, 0xC0),
-	_INIT_CMD(0x00, 0xC8, 0xC4),
-	_INIT_CMD(0x00, 0xC9, 0x00),
-	_INIT_CMD(0x00, 0xCA, 0x00),
-	_INIT_CMD(0x00, 0xCB, 0x16),
-	_INIT_CMD(0x00, 0xCC, 0xAF),
-	_INIT_CMD(0x00, 0xCD, 0xFF),
-	_INIT_CMD(0x00, 0xCE, 0xFF),
-	_INIT_CMD(0x00, 0xB0, 0x08),
-	_INIT_CMD(0x00, 0xB1, 0x04),
-	_INIT_CMD(0x00, 0xB2, 0x08),
-	_INIT_CMD(0x00, 0xB3, 0x19),
-	_INIT_CMD(0x00, 0xB4, 0x31),
-	_INIT_CMD(0x00, 0xB5, 0x46),
-	_INIT_CMD(0x00, 0xB6, 0x55),
-	_INIT_CMD(0x00, 0xB7, 0x6E),
-	_INIT_CMD(0x00, 0xB8, 0x92),
-	_INIT_CMD(0x00, 0xB9, 0xD4),
-	_INIT_CMD(0x00, 0xBA, 0x1B),
-	_INIT_CMD(0x05, 0xBB, 0x9B),
-	_INIT_CMD(0x00, 0xBC, 0x28),
-	_INIT_CMD(0x00, 0xBD, 0x2D),
-	_INIT_CMD(0x00, 0xBE, 0xC3),
-	_INIT_CMD(0x00, 0xBF, 0x2F),
-	_INIT_CMD(0x00, 0xC0, 0x62),
-	_INIT_CMD(0x00, 0xC1, 0x99),
-	_INIT_CMD(0x00, 0xC2, 0xAB),
-	_INIT_CMD(0x00, 0xC3, 0xBF),
-	_INIT_CMD(0x00, 0xC4, 0xCF),
-	_INIT_CMD(0x00, 0xC5, 0xDF),
-	_INIT_CMD(0x00, 0xC6, 0xF0),
-	_INIT_CMD(0x00, 0xC7, 0xF9),
-	_INIT_CMD(0x00, 0xC8, 0xFC),
-	_INIT_CMD(0x00, 0xC9, 0x00),
-	_INIT_CMD(0x00, 0xCA, 0x00),
-	_INIT_CMD(0x00, 0xCB, 0x16),
-	_INIT_CMD(0x00, 0xCC, 0xAF),
-	_INIT_CMD(0x00, 0xCD, 0xFF),
-	_INIT_CMD(0x00, 0xCE, 0xFF),
-	_INIT_CMD(0x00, 0xB0, 0x09),
-	_INIT_CMD(0x00, 0xB1, 0x04),
-	_INIT_CMD(0x00, 0xB2, 0x05),
-	_INIT_CMD(0x00, 0xB3, 0x17),
-	_INIT_CMD(0x00, 0xB4, 0x2E),
-	_INIT_CMD(0x00, 0xB5, 0x42),
-	_INIT_CMD(0x00, 0xB6, 0x51),
-	_INIT_CMD(0x00, 0xB7, 0x69),
-	_INIT_CMD(0x00, 0xB8, 0x88),
-	_INIT_CMD(0x00, 0xB9, 0xC9),
-	_INIT_CMD(0x00, 0xBA, 0x0C),
-	_INIT_CMD(0x05, 0xBB, 0x86),
-	_INIT_CMD(0x00, 0xBC, 0x03),
-	_INIT_CMD(0x00, 0xBD, 0x08),
-	_INIT_CMD(0x00, 0xBE, 0x95),
-	_INIT_CMD(0x00, 0xBF, 0x05),
-	_INIT_CMD(0x00, 0xC0, 0x35),
-	_INIT_CMD(0x00, 0xC1, 0x62),
-	_INIT_CMD(0x00, 0xC2, 0x81),
-	_INIT_CMD(0x00, 0xC3, 0x96),
-	_INIT_CMD(0x00, 0xC4, 0x9E),
-	_INIT_CMD(0x00, 0xC5, 0xA5),
-	_INIT_CMD(0x00, 0xC6, 0xAD),
-	_INIT_CMD(0x00, 0xC7, 0xB1),
-	_INIT_CMD(0x00, 0xC8, 0xB4),
-	_INIT_CMD(0x00, 0xC9, 0x00),
-	_INIT_CMD(0x00, 0xCA, 0x00),
-	_INIT_CMD(0x00, 0xCB, 0x16),
-	_INIT_CMD(0x00, 0xCC, 0xAF),
-	_INIT_CMD(0x00, 0xCD, 0xFF),
-	_INIT_CMD(0x00, 0xCE, 0xFF),
-	_INIT_CMD(0x00, 0xB0, 0x0A),
-	_INIT_CMD(0x00, 0xB1, 0x00),
-	_INIT_CMD(0x00, 0xB2, 0x09),
-	_INIT_CMD(0x00, 0xB3, 0x19),
-	_INIT_CMD(0x00, 0xB4, 0x2F),
-	_INIT_CMD(0x00, 0xB5, 0x44),
-	_INIT_CMD(0x00, 0xB6, 0x52),
-	_INIT_CMD(0x00, 0xB7, 0x6A),
-	_INIT_CMD(0x00, 0xB8, 0x8A),
-	_INIT_CMD(0x00, 0xB9, 0xCA),
-	_INIT_CMD(0x00, 0xBA, 0x0C),
-	_INIT_CMD(0x05, 0xBB, 0x87),
-	_INIT_CMD(0x00, 0xBC, 0x06),
-	_INIT_CMD(0x00, 0xBD, 0x0A),
-	_INIT_CMD(0x00, 0xBE, 0x9B),
-	_INIT_CMD(0x00, 0xBF, 0x0C),
-	_INIT_CMD(0x00, 0xC0, 0x3D),
-	_INIT_CMD(0x00, 0xC1, 0x71),
-	_INIT_CMD(0x00, 0xC2, 0x90),
-	_INIT_CMD(0x00, 0xC3, 0xA0),
-	_INIT_CMD(0x00, 0xC4, 0xA8),
-	_INIT_CMD(0x00, 0xC5, 0xB1),
-	_INIT_CMD(0x00, 0xC6, 0xBB),
-	_INIT_CMD(0x00, 0xC7, 0xC0),
-	_INIT_CMD(0x00, 0xC8, 0xC4),
-	_INIT_CMD(0x00, 0xC9, 0x00),
-	_INIT_CMD(0x00, 0xCA, 0x00),
-	_INIT_CMD(0x00, 0xCB, 0x16),
-	_INIT_CMD(0x00, 0xCC, 0xAF),
-	_INIT_CMD(0x00, 0xCD, 0xFF),
-	_INIT_CMD(0x00, 0xCE, 0xFF),
-	_INIT_CMD(0x00, 0xB0, 0x0B),
-	_INIT_CMD(0x00, 0xB1, 0x04),
-	_INIT_CMD(0x00, 0xB2, 0x08),
-	_INIT_CMD(0x00, 0xB3, 0x19),
-	_INIT_CMD(0x00, 0xB4, 0x31),
-	_INIT_CMD(0x00, 0xB5, 0x46),
-	_INIT_CMD(0x00, 0xB6, 0x55),
-	_INIT_CMD(0x00, 0xB7, 0x6E),
-	_INIT_CMD(0x00, 0xB8, 0x92),
-	_INIT_CMD(0x00, 0xB9, 0xD4),
-	_INIT_CMD(0x00, 0xBA, 0x1B),
-	_INIT_CMD(0x05, 0xBB, 0x9B),
-	_INIT_CMD(0x00, 0xBC, 0x28),
-	_INIT_CMD(0x00, 0xBD, 0x2D),
-	_INIT_CMD(0x00, 0xBE, 0xC3),
-	_INIT_CMD(0x00, 0xBF, 0x2F),
-	_INIT_CMD(0x00, 0xC0, 0x62),
-	_INIT_CMD(0x00, 0xC1, 0x99),
-	_INIT_CMD(0x00, 0xC2, 0xAB),
-	_INIT_CMD(0x00, 0xC3, 0xBF),
-	_INIT_CMD(0x00, 0xC4, 0xCF),
-	_INIT_CMD(0x00, 0xC5, 0xDF),
-	_INIT_CMD(0x00, 0xC6, 0xF0),
-	_INIT_CMD(0x00, 0xC7, 0xF9),
-	_INIT_CMD(0x00, 0xC8, 0xFC),
-	_INIT_CMD(0x00, 0xC9, 0x00),
-	_INIT_CMD(0x00, 0xCA, 0x00),
-	_INIT_CMD(0x00, 0xCB, 0x16),
-	_INIT_CMD(0x00, 0xCC, 0xAF),
-	_INIT_CMD(0x00, 0xCD, 0xFF),
-	_INIT_CMD(0x00, 0xCE, 0xFF),
-	_INIT_CMD(0x00, 0xB0, 0x0C),
-	_INIT_CMD(0x00, 0xB1, 0x04),
-	_INIT_CMD(0x00, 0xB2, 0x05),
-	_INIT_CMD(0x00, 0xB3, 0x17),
-	_INIT_CMD(0x00, 0xB4, 0x2E),
-	_INIT_CMD(0x00, 0xB5, 0x42),
-	_INIT_CMD(0x00, 0xB6, 0x51),
-	_INIT_CMD(0x00, 0xB7, 0x69),
-	_INIT_CMD(0x00, 0xB8, 0x88),
-	_INIT_CMD(0x00, 0xB9, 0xC9),
-	_INIT_CMD(0x00, 0xBA, 0x0C),
-	_INIT_CMD(0x05, 0xBB, 0x86),
-	_INIT_CMD(0x00, 0xBC, 0x03),
-	_INIT_CMD(0x00, 0xBD, 0x08),
-	_INIT_CMD(0x00, 0xBE, 0x95),
-	_INIT_CMD(0x00, 0xBF, 0x05),
-	_INIT_CMD(0x00, 0xC0, 0x35),
-	_INIT_CMD(0x00, 0xC1, 0x62),
-	_INIT_CMD(0x00, 0xC2, 0x81),
-	_INIT_CMD(0x00, 0xC3, 0x96),
-	_INIT_CMD(0x00, 0xC4, 0x9E),
-	_INIT_CMD(0x00, 0xC5, 0xA5),
-	_INIT_CMD(0x00, 0xC6, 0xAD),
-	_INIT_CMD(0x00, 0xC7, 0xB1),
-	_INIT_CMD(0x00, 0xC8, 0xB4),
-	_INIT_CMD(0x00, 0xC9, 0x00),
-	_INIT_CMD(0x00, 0xCA, 0x00),
-	_INIT_CMD(0x00, 0xCB, 0x16),
-	_INIT_CMD(0x00, 0xCC, 0xAF),
-	_INIT_CMD(0x00, 0xCD, 0xFF),
-	_INIT_CMD(0x64, 0xCE, 0xFF),
-	_INIT_CMD(0x00, 0xB0, 0x00),
-	_INIT_CMD(0x00, 0xB3, 0x08),
-	_INIT_CMD(0x00, 0xB0, 0x04),
-	_INIT_CMD(0x0A, 0xB8, 0x68),
-	_INIT_CMD(0x78, 0x11),
-	_INIT_CMD(0x14, 0x29),
+	_INIT_CMD(0xB0, 0x05),
+	_INIT_CMD(0xB1, 0xE5),
+	_INIT_CMD(0xB3, 0x52),
+	_INIT_CMD(0xC0, 0x00),
+	_INIT_CMD(0xC2, 0x57),
+	_INIT_CMD(0xD9, 0x85),
+	_INIT_CMD(0xB0, 0x01),
+	_INIT_CMD(0xC8, 0x00),
+	_INIT_CMD(0xC9, 0x00),
+	_INIT_CMD(0xCC, 0x26),
+	_INIT_CMD(0xCD, 0x26),
+	_INIT_CMD(0xDC, 0x00),
+	_INIT_CMD(0xDD, 0x00),
+	_INIT_CMD(0xE0, 0x26),
+	_INIT_CMD(0xE1, 0x26),
+	_INIT_CMD(0xB0, 0x03),
+	_INIT_CMD(0xC3, 0x2A),
+	_INIT_CMD(0xE7, 0x2A),
+	_INIT_CMD(0xC5, 0x2A),
+	_INIT_CMD(0xDE, 0x2A),
+	_INIT_CMD(0xBC, 0x02),
+	_INIT_CMD(0xCB, 0x02),
+	_INIT_CMD(0xB0, 0x00),
+	_INIT_CMD(0xB6, 0x03),
+	_INIT_CMD(0xBA, 0x8B),
+	_INIT_CMD(0xBF, 0x15),
+	_INIT_CMD(0xC0, 0x18),
+	_INIT_CMD(0xC2, 0x14),
+	_INIT_CMD(0xC3, 0x02),
+	_INIT_CMD(0xC4, 0x14),
+	_INIT_CMD(0xC5, 0x02),
+	_INIT_CMD(0xCC, 0x0A),
+	_INIT_CMD(0xB0, 0x06),
+	_INIT_CMD(0xC0, 0xA5),
+	_INIT_CMD(0xD5, 0x20),
+	_INIT_CMD(0xC0, 0x00),
+	_INIT_CMD(0xB0, 0x02),
+	_INIT_CMD(0xC0, 0x00),
+	_INIT_CMD(0xC1, 0x02),
+	_INIT_CMD(0xC2, 0x06),
+	_INIT_CMD(0xC3, 0x16),
+	_INIT_CMD(0xC4, 0x0E),
+	_INIT_CMD(0xC5, 0x18),
+	_INIT_CMD(0xC6, 0x26),
+	_INIT_CMD(0xC7, 0x32),
+	_INIT_CMD(0xC8, 0x3F),
+	_INIT_CMD(0xC9, 0x3F),
+	_INIT_CMD(0xCA, 0x3F),
+	_INIT_CMD(0xCB, 0x3F),
+	_INIT_CMD(0xCC, 0x3D),
+	_INIT_CMD(0xCD, 0x2F),
+	_INIT_CMD(0xCE, 0x2F),
+	_INIT_CMD(0xCF, 0x2F),
+	_INIT_CMD(0xD0, 0x07),
+	_INIT_CMD(0xD2, 0x00),
+	_INIT_CMD(0xD3, 0x02),
+	_INIT_CMD(0xD4, 0x06),
+	_INIT_CMD(0xD5, 0x12),
+	_INIT_CMD(0xD6, 0x0A),
+	_INIT_CMD(0xD7, 0x14),
+	_INIT_CMD(0xD8, 0x22),
+	_INIT_CMD(0xD9, 0x2E),
+	_INIT_CMD(0xDA, 0x3D),
+	_INIT_CMD(0xDB, 0x3F),
+	_INIT_CMD(0xDC, 0x3F),
+	_INIT_CMD(0xDD, 0x3F),
+	_INIT_CMD(0xDE, 0x3D),
+	_INIT_CMD(0xDF, 0x2F),
+	_INIT_CMD(0xE0, 0x2F),
+	_INIT_CMD(0xE1, 0x2F),
+	_INIT_CMD(0xE2, 0x07),
+	_INIT_CMD(0xB0, 0x07),
+	_INIT_CMD(0xB1, 0x18),
+	_INIT_CMD(0xB2, 0x19),
+	_INIT_CMD(0xB3, 0x2E),
+	_INIT_CMD(0xB4, 0x52),
+	_INIT_CMD(0xB5, 0x72),
+	_INIT_CMD(0xB6, 0x8C),
+	_INIT_CMD(0xB7, 0xBD),
+	_INIT_CMD(0xB8, 0xEB),
+	_INIT_CMD(0xB9, 0x47),
+	_INIT_CMD(0xBA, 0x96),
+	_INIT_CMD(0xBB, 0x1E),
+	_INIT_CMD(0xBC, 0x90),
+	_INIT_CMD(0xBD, 0x93),
+	_INIT_CMD(0xBE, 0xFA),
+	_INIT_CMD(0xBF, 0x56),
+	_INIT_CMD(0xC0, 0x8C),
+	_INIT_CMD(0xC1, 0xB7),
+	_INIT_CMD(0xC2, 0xCC),
+	_INIT_CMD(0xC3, 0xDF),
+	_INIT_CMD(0xC4, 0xE8),
+	_INIT_CMD(0xC5, 0xF0),
+	_INIT_CMD(0xC6, 0xF8),
+	_INIT_CMD(0xC7, 0xFA),
+	_INIT_CMD(0xC8, 0xFC),
+	_INIT_CMD(0xC9, 0x00),
+	_INIT_CMD(0xCA, 0x00),
+	_INIT_CMD(0xCB, 0x5A),
+	_INIT_CMD(0xCC, 0xAF),
+	_INIT_CMD(0xCD, 0xFF),
+	_INIT_CMD(0xCE, 0xFF),
+	_INIT_CMD(0xB0, 0x08),
+	_INIT_CMD(0xB1, 0x04),
+	_INIT_CMD(0xB2, 0x15),
+	_INIT_CMD(0xB3, 0x2D),
+	_INIT_CMD(0xB4, 0x51),
+	_INIT_CMD(0xB5, 0x72),
+	_INIT_CMD(0xB6, 0x8D),
+	_INIT_CMD(0xB7, 0xBE),
+	_INIT_CMD(0xB8, 0xED),
+	_INIT_CMD(0xB9, 0x4A),
+	_INIT_CMD(0xBA, 0x9A),
+	_INIT_CMD(0xBB, 0x23),
+	_INIT_CMD(0xBC, 0x95),
+	_INIT_CMD(0xBD, 0x98),
+	_INIT_CMD(0xBE, 0xFF),
+	_INIT_CMD(0xBF, 0x59),
+	_INIT_CMD(0xC0, 0x8E),
+	_INIT_CMD(0xC1, 0xB9),
+	_INIT_CMD(0xC2, 0xCD),
+	_INIT_CMD(0xC3, 0xDF),
+	_INIT_CMD(0xC4, 0xE8),
+	_INIT_CMD(0xC5, 0xF0),
+	_INIT_CMD(0xC6, 0xF8),
+	_INIT_CMD(0xC7, 0xFA),
+	_INIT_CMD(0xC8, 0xFC),
+	_INIT_CMD(0xC9, 0x00),
+	_INIT_CMD(0xCA, 0x00),
+	_INIT_CMD(0xCB, 0x5A),
+	_INIT_CMD(0xCC, 0xAF),
+	_INIT_CMD(0xCD, 0xFF),
+	_INIT_CMD(0xCE, 0xFF),
+	_INIT_CMD(0xB0, 0x09),
+	_INIT_CMD(0xB1, 0x04),
+	_INIT_CMD(0xB2, 0x2C),
+	_INIT_CMD(0xB3, 0x36),
+	_INIT_CMD(0xB4, 0x53),
+	_INIT_CMD(0xB5, 0x73),
+	_INIT_CMD(0xB6, 0x8E),
+	_INIT_CMD(0xB7, 0xC0),
+	_INIT_CMD(0xB8, 0xEF),
+	_INIT_CMD(0xB9, 0x4C),
+	_INIT_CMD(0xBA, 0x9D),
+	_INIT_CMD(0xBB, 0x25),
+	_INIT_CMD(0xBC, 0x96),
+	_INIT_CMD(0xBD, 0x9A),
+	_INIT_CMD(0xBE, 0x01),
+	_INIT_CMD(0xBF, 0x59),
+	_INIT_CMD(0xC0, 0x8E),
+	_INIT_CMD(0xC1, 0xB9),
+	_INIT_CMD(0xC2, 0xCD),
+	_INIT_CMD(0xC3, 0xDF),
+	_INIT_CMD(0xC4, 0xE8),
+	_INIT_CMD(0xC5, 0xF0),
+	_INIT_CMD(0xC6, 0xF8),
+	_INIT_CMD(0xC7, 0xFA),
+	_INIT_CMD(0xC8, 0xFC),
+	_INIT_CMD(0xC9, 0x00),
+	_INIT_CMD(0xCA, 0x00),
+	_INIT_CMD(0xCB, 0x5A),
+	_INIT_CMD(0xCC, 0xBF),
+	_INIT_CMD(0xCD, 0xFF),
+	_INIT_CMD(0xCE, 0xFF),
+	_INIT_CMD(0xB0, 0x0A),
+	_INIT_CMD(0xB1, 0x18),
+	_INIT_CMD(0xB2, 0x19),
+	_INIT_CMD(0xB3, 0x2E),
+	_INIT_CMD(0xB4, 0x52),
+	_INIT_CMD(0xB5, 0x72),
+	_INIT_CMD(0xB6, 0x8C),
+	_INIT_CMD(0xB7, 0xBD),
+	_INIT_CMD(0xB8, 0xEB),
+	_INIT_CMD(0xB9, 0x47),
+	_INIT_CMD(0xBA, 0x96),
+	_INIT_CMD(0xBB, 0x1E),
+	_INIT_CMD(0xBC, 0x90),
+	_INIT_CMD(0xBD, 0x93),
+	_INIT_CMD(0xBE, 0xFA),
+	_INIT_CMD(0xBF, 0x56),
+	_INIT_CMD(0xC0, 0x8C),
+	_INIT_CMD(0xC1, 0xB7),
+	_INIT_CMD(0xC2, 0xCC),
+	_INIT_CMD(0xC3, 0xDF),
+	_INIT_CMD(0xC4, 0xE8),
+	_INIT_CMD(0xC5, 0xF0),
+	_INIT_CMD(0xC6, 0xF8),
+	_INIT_CMD(0xC7, 0xFA),
+	_INIT_CMD(0xC8, 0xFC),
+	_INIT_CMD(0xC9, 0x00),
+	_INIT_CMD(0xCA, 0x00),
+	_INIT_CMD(0xCB, 0x5A),
+	_INIT_CMD(0xCC, 0xAF),
+	_INIT_CMD(0xCD, 0xFF),
+	_INIT_CMD(0xCE, 0xFF),
+	_INIT_CMD(0xB0, 0x0B),
+	_INIT_CMD(0xB1, 0x04),
+	_INIT_CMD(0xB2, 0x15),
+	_INIT_CMD(0xB3, 0x2D),
+	_INIT_CMD(0xB4, 0x51),
+	_INIT_CMD(0xB5, 0x72),
+	_INIT_CMD(0xB6, 0x8D),
+	_INIT_CMD(0xB7, 0xBE),
+	_INIT_CMD(0xB8, 0xED),
+	_INIT_CMD(0xB9, 0x4A),
+	_INIT_CMD(0xBA, 0x9A),
+	_INIT_CMD(0xBB, 0x23),
+	_INIT_CMD(0xBC, 0x95),
+	_INIT_CMD(0xBD, 0x98),
+	_INIT_CMD(0xBE, 0xFF),
+	_INIT_CMD(0xBF, 0x59),
+	_INIT_CMD(0xC0, 0x8E),
+	_INIT_CMD(0xC1, 0xB9),
+	_INIT_CMD(0xC2, 0xCD),
+	_INIT_CMD(0xC3, 0xDF),
+	_INIT_CMD(0xC4, 0xE8),
+	_INIT_CMD(0xC5, 0xF0),
+	_INIT_CMD(0xC6, 0xF8),
+	_INIT_CMD(0xC7, 0xFA),
+	_INIT_CMD(0xC8, 0xFC),
+	_INIT_CMD(0xC9, 0x00),
+	_INIT_CMD(0xCA, 0x00),
+	_INIT_CMD(0xCB, 0x5A),
+	_INIT_CMD(0xCC, 0xAF),
+	_INIT_CMD(0xCD, 0xFF),
+	_INIT_CMD(0xCE, 0xFF),
+	_INIT_CMD(0xB0, 0x0C),
+	_INIT_CMD(0xB1, 0x04),
+	_INIT_CMD(0xB2, 0x2C),
+	_INIT_CMD(0xB3, 0x36),
+	_INIT_CMD(0xB4, 0x53),
+	_INIT_CMD(0xB5, 0x73),
+	_INIT_CMD(0xB6, 0x8E),
+	_INIT_CMD(0xB7, 0xC0),
+	_INIT_CMD(0xB8, 0xEF),
+	_INIT_CMD(0xB9, 0x4C),
+	_INIT_CMD(0xBA, 0x9D),
+	_INIT_CMD(0xBB, 0x25),
+	_INIT_CMD(0xBC, 0x96),
+	_INIT_CMD(0xBD, 0x9A),
+	_INIT_CMD(0xBE, 0x01),
+	_INIT_CMD(0xBF, 0x59),
+	_INIT_CMD(0xC0, 0x8E),
+	_INIT_CMD(0xC1, 0xB9),
+	_INIT_CMD(0xC2, 0xCD),
+	_INIT_CMD(0xC3, 0xDF),
+	_INIT_CMD(0xC4, 0xE8),
+	_INIT_CMD(0xC5, 0xF0),
+	_INIT_CMD(0xC6, 0xF8),
+	_INIT_CMD(0xC7, 0xFA),
+	_INIT_CMD(0xC8, 0xFC),
+	_INIT_CMD(0xC9, 0x00),
+	_INIT_CMD(0xCA, 0x00),
+	_INIT_CMD(0xCB, 0x5A),
+	_INIT_CMD(0xCC, 0xBF),
+	_INIT_CMD(0xCD, 0xFF),
+	_INIT_CMD(0xCE, 0xFF),
+	_INIT_CMD(0xB0, 0x04),
+	_INIT_CMD(0xB5, 0x02),
+	_INIT_CMD(0xB6, 0x01),
 
 	{},
 };
@@ -573,320 +542,298 @@ static const struct panel_desc boe_himax8279d8p_panel_desc = {
 	.bpc = 8,
 	.width_mm = 107,
 	.height_mm = 172,
-	.delay_t1 = 5000,
-	.reset_delay_t2 = 14000,
-	.reset_delay_t3 = 1000,
-	.reset_delay_t4 = 1000,
-	.reset_delay_t5 = 5000,
 	.mode_flags = MIPI_DSI_MODE_VIDEO | MIPI_DSI_MODE_VIDEO_SYNC_PULSE |
 			MIPI_DSI_CLOCK_NON_CONTINUOUS | MIPI_DSI_MODE_LPM,
 	.format = MIPI_DSI_FMT_RGB888,
 	.lanes = 4,
 	.on_cmds = boe_himax8279d8p_on_cmds,
-	.off_cmds = default_off_cmds,
 };
 
 /* 10 inch */
 static const struct panel_cmd boe_himax8279d10p_on_cmds[] = {
-	_INIT_CMD(0x00, 0xB0, 0x05),
-	_INIT_CMD(0x00, 0xB1, 0xE5),
-	_INIT_CMD(0x00, 0xB3, 0x52),
-	_INIT_CMD(0x00, 0xB0, 0x00),
-	_INIT_CMD(0x00, 0xB3, 0x88),
-	_INIT_CMD(0x00, 0xB0, 0x04),
-	_INIT_CMD(0x00, 0xB8, 0x00),
-	_INIT_CMD(0x00, 0xB0, 0x00),
-	_INIT_CMD(0x00, 0xB2, 0x50),
-	_INIT_CMD(0x00, 0xB6, 0x03),
-	_INIT_CMD(0x00, 0xBA, 0x8B),
-	_INIT_CMD(0x00, 0xBF, 0x1A),
-	_INIT_CMD(0x00, 0xC0, 0x0F),
-	_INIT_CMD(0x00, 0xC2, 0x0C),
-	_INIT_CMD(0x00, 0xC3, 0x02),
-	_INIT_CMD(0x00, 0xC4, 0x0C),
-	_INIT_CMD(0x00, 0xC5, 0x02),
-	_INIT_CMD(0x00, 0xB0, 0x01),
-	_INIT_CMD(0x00, 0xE0, 0x26),
-	_INIT_CMD(0x00, 0xE1, 0x26),
-	_INIT_CMD(0x00, 0xDC, 0x00),
-	_INIT_CMD(0x00, 0xDD, 0x00),
-	_INIT_CMD(0x00, 0xCC, 0x26),
-	_INIT_CMD(0x00, 0xCD, 0x26),
-	_INIT_CMD(0x00, 0xC8, 0x00),
-	_INIT_CMD(0x00, 0xC9, 0x00),
-	_INIT_CMD(0x00, 0xD2, 0x04),
-	_INIT_CMD(0x00, 0xD3, 0x04),
-	_INIT_CMD(0x00, 0xE6, 0x03),
-	_INIT_CMD(0x00, 0xE7, 0x03),
-	_INIT_CMD(0x00, 0xC4, 0x08),
-	_INIT_CMD(0x00, 0xC5, 0x08),
-	_INIT_CMD(0x00, 0xD8, 0x07),
-	_INIT_CMD(0x00, 0xD9, 0x07),
-	_INIT_CMD(0x00, 0xC2, 0x06),
-	_INIT_CMD(0x00, 0xC3, 0x06),
-	_INIT_CMD(0x00, 0xD6, 0x05),
-	_INIT_CMD(0x00, 0xD7, 0x05),
-	_INIT_CMD(0x00, 0xC0, 0x0C),
-	_INIT_CMD(0x00, 0xC1, 0x0C),
-	_INIT_CMD(0x00, 0xD4, 0x0B),
-	_INIT_CMD(0x00, 0xD5, 0x0B),
-	_INIT_CMD(0x00, 0xCA, 0x0A),
-	_INIT_CMD(0x00, 0xCB, 0x0A),
-	_INIT_CMD(0x00, 0xDE, 0x09),
-	_INIT_CMD(0x00, 0xDF, 0x09),
-	_INIT_CMD(0x00, 0xC6, 0x26),
-	_INIT_CMD(0x00, 0xC7, 0x26),
-	_INIT_CMD(0x00, 0xCE, 0x00),
-	_INIT_CMD(0x00, 0xCF, 0x00),
-	_INIT_CMD(0x00, 0xDA, 0x26),
-	_INIT_CMD(0x00, 0xDB, 0x26),
-	_INIT_CMD(0x00, 0xE2, 0x00),
-	_INIT_CMD(0x00, 0xE3, 0x00),
-	_INIT_CMD(0x00, 0xB0, 0x02),
-	_INIT_CMD(0x00, 0xC0, 0x00),
-	_INIT_CMD(0x00, 0xC1, 0x07),
-	_INIT_CMD(0x00, 0xC2, 0x0D),
-	_INIT_CMD(0x00, 0xC3, 0x18),
-	_INIT_CMD(0x00, 0xC4, 0x27),
-	_INIT_CMD(0x00, 0xC5, 0x28),
-	_INIT_CMD(0x00, 0xC6, 0x30),
-	_INIT_CMD(0x00, 0xC7, 0x2E),
-	_INIT_CMD(0x00, 0xC8, 0x2F),
-	_INIT_CMD(0x00, 0xC9, 0x1A),
-	_INIT_CMD(0x00, 0xCA, 0x20),
-	_INIT_CMD(0x00, 0xCB, 0x29),
-	_INIT_CMD(0x00, 0xCC, 0x26),
-	_INIT_CMD(0x00, 0xCD, 0x32),
-	_INIT_CMD(0x00, 0xCE, 0x33),
-	_INIT_CMD(0x00, 0xCF, 0x31),
-	_INIT_CMD(0x00, 0xD0, 0x06),
-	_INIT_CMD(0x00, 0xD2, 0x00),
-	_INIT_CMD(0x00, 0xD3, 0x07),
-	_INIT_CMD(0x00, 0xD4, 0x12),
-	_INIT_CMD(0x00, 0xD5, 0x26),
-	_INIT_CMD(0x00, 0xD6, 0x3D),
-	_INIT_CMD(0x00, 0xD7, 0x3F),
-	_INIT_CMD(0x00, 0xD8, 0x3F),
-	_INIT_CMD(0x00, 0xD9, 0x3F),
-	_INIT_CMD(0x00, 0xDA, 0x3F),
-	_INIT_CMD(0x00, 0xDB, 0x3F),
-	_INIT_CMD(0x00, 0xDC, 0x3F),
-	_INIT_CMD(0x00, 0xDD, 0x3F),
-	_INIT_CMD(0x00, 0xDE, 0x3F),
-	_INIT_CMD(0x00, 0xDF, 0x3A),
-	_INIT_CMD(0x00, 0xE0, 0x37),
-	_INIT_CMD(0x00, 0xE1, 0x35),
-	_INIT_CMD(0x00, 0xE2, 0x07),
-	_INIT_CMD(0x00, 0xB0, 0x03),
-	_INIT_CMD(0x00, 0xC8, 0x0B),
-	_INIT_CMD(0x00, 0xC9, 0x07),
-	_INIT_CMD(0x00, 0xC3, 0x00),
-	_INIT_CMD(0x00, 0xE7, 0x00),
-	_INIT_CMD(0x00, 0xC5, 0x2A),
-	_INIT_CMD(0x00, 0xDE, 0x2A),
-	_INIT_CMD(0x00, 0xCA, 0x43),
-	_INIT_CMD(0x00, 0xC9, 0x07),
-	_INIT_CMD(0x00, 0xE4, 0xC0),
-	_INIT_CMD(0x00, 0xE5, 0x0D),
-	_INIT_CMD(0x00, 0xCB, 0x00),
-	_INIT_CMD(0x00, 0xB0, 0x06),
-	_INIT_CMD(0x00, 0xB8, 0xA5),
-	_INIT_CMD(0x00, 0xC0, 0xA5),
-	_INIT_CMD(0x00, 0xC7, 0x0F),
-	_INIT_CMD(0x00, 0xD5, 0x32),
-	_INIT_CMD(0x00, 0xB8, 0x00),
-	_INIT_CMD(0x00, 0xC0, 0x00),
-	_INIT_CMD(0x00, 0xBC, 0x00),
-	_INIT_CMD(0x00, 0xB0, 0x07),
-	_INIT_CMD(0x00, 0xB1, 0x00),
-	_INIT_CMD(0x00, 0xB2, 0x09),
-	_INIT_CMD(0x00, 0xB3, 0x19),
-	_INIT_CMD(0x00, 0xB4, 0x2F),
-	_INIT_CMD(0x00, 0xB5, 0x44),
-	_INIT_CMD(0x00, 0xB6, 0x52),
-	_INIT_CMD(0x00, 0xB7, 0x6A),
-	_INIT_CMD(0x00, 0xB8, 0x8A),
-	_INIT_CMD(0x00, 0xB9, 0xCA),
-	_INIT_CMD(0x00, 0xBA, 0x0C),
-	_INIT_CMD(0x00, 0xBB, 0x87),
-	_INIT_CMD(0x00, 0xBC, 0x06),
-	_INIT_CMD(0x00, 0xBD, 0x0A),
-	_INIT_CMD(0x00, 0xBE, 0x9B),
-	_INIT_CMD(0x00, 0xBF, 0x0C),
-	_INIT_CMD(0x00, 0xC0, 0x3D),
-	_INIT_CMD(0x00, 0xC1, 0x71),
-	_INIT_CMD(0x00, 0xC2, 0x90),
-	_INIT_CMD(0x00, 0xC3, 0xA0),
-	_INIT_CMD(0x00, 0xC4, 0xA8),
-	_INIT_CMD(0x00, 0xC5, 0xB1),
-	_INIT_CMD(0x00, 0xC6, 0xBB),
-	_INIT_CMD(0x00, 0xC7, 0xC0),
-	_INIT_CMD(0x00, 0xC8, 0xC4),
-	_INIT_CMD(0x00, 0xC9, 0x00),
-	_INIT_CMD(0x00, 0xCA, 0x00),
-	_INIT_CMD(0x00, 0xCB, 0x16),
-	_INIT_CMD(0x00, 0xCC, 0xAF),
-	_INIT_CMD(0x00, 0xCD, 0xFF),
-	_INIT_CMD(0x00, 0xCE, 0xFF),
-	_INIT_CMD(0x00, 0xB0, 0x08),
-	_INIT_CMD(0x00, 0xB1, 0x04),
-	_INIT_CMD(0x00, 0xB2, 0x08),
-	_INIT_CMD(0x00, 0xB3, 0x19),
-	_INIT_CMD(0x00, 0xB4, 0x31),
-	_INIT_CMD(0x00, 0xB5, 0x46),
-	_INIT_CMD(0x00, 0xB6, 0x55),
-	_INIT_CMD(0x00, 0xB7, 0x6E),
-	_INIT_CMD(0x00, 0xB8, 0x92),
-	_INIT_CMD(0x00, 0xB9, 0xD4),
-	_INIT_CMD(0x00, 0xBA, 0x1B),
-	_INIT_CMD(0x00, 0xBB, 0x9B),
-	_INIT_CMD(0x00, 0xBC, 0x28),
-	_INIT_CMD(0x00, 0xBD, 0x2D),
-	_INIT_CMD(0x00, 0xBE, 0xC3),
-	_INIT_CMD(0x00, 0xBF, 0x2F),
-	_INIT_CMD(0x00, 0xC0, 0x62),
-	_INIT_CMD(0x00, 0xC1, 0x99),
-	_INIT_CMD(0x00, 0xC2, 0xAB),
-	_INIT_CMD(0x00, 0xC3, 0xBF),
-	_INIT_CMD(0x00, 0xC4, 0xCF),
-	_INIT_CMD(0x00, 0xC5, 0xDF),
-	_INIT_CMD(0x00, 0xC6, 0xF0),
-	_INIT_CMD(0x00, 0xC7, 0xF9),
-	_INIT_CMD(0x00, 0xC8, 0xFC),
-	_INIT_CMD(0x00, 0xC9, 0x00),
-	_INIT_CMD(0x00, 0xCA, 0x00),
-	_INIT_CMD(0x00, 0xCB, 0x16),
-	_INIT_CMD(0x00, 0xCC, 0xAF),
-	_INIT_CMD(0x00, 0xCD, 0xFF),
-	_INIT_CMD(0x00, 0xCE, 0xFF),
-	_INIT_CMD(0x00, 0xB0, 0x09),
-	_INIT_CMD(0x00, 0xB1, 0x04),
-	_INIT_CMD(0x00, 0xB2, 0x05),
-	_INIT_CMD(0x00, 0xB3, 0x17),
-	_INIT_CMD(0x00, 0xB4, 0x2E),
-	_INIT_CMD(0x00, 0xB5, 0x42),
-	_INIT_CMD(0x00, 0xB6, 0x51),
-	_INIT_CMD(0x00, 0xB7, 0x69),
-	_INIT_CMD(0x00, 0xB8, 0x88),
-	_INIT_CMD(0x00, 0xB9, 0xC9),
-	_INIT_CMD(0x00, 0xBA, 0x0C),
-	_INIT_CMD(0x00, 0xBB, 0x86),
-	_INIT_CMD(0x00, 0xBC, 0x03),
-	_INIT_CMD(0x00, 0xBD, 0x08),
-	_INIT_CMD(0x00, 0xBE, 0x95),
-	_INIT_CMD(0x00, 0xBF, 0x05),
-	_INIT_CMD(0x00, 0xC0, 0x35),
-	_INIT_CMD(0x00, 0xC1, 0x62),
-	_INIT_CMD(0x00, 0xC2, 0x81),
-	_INIT_CMD(0x00, 0xC3, 0x96),
-	_INIT_CMD(0x00, 0xC4, 0x9E),
-	_INIT_CMD(0x00, 0xC5, 0xA5),
-	_INIT_CMD(0x00, 0xC6, 0xAD),
-	_INIT_CMD(0x00, 0xC7, 0xB1),
-	_INIT_CMD(0x00, 0xC8, 0xB4),
-	_INIT_CMD(0x00, 0xC9, 0x00),
-	_INIT_CMD(0x00, 0xCA, 0x00),
-	_INIT_CMD(0x00, 0xCB, 0x16),
-	_INIT_CMD(0x00, 0xCC, 0xAF),
-	_INIT_CMD(0x00, 0xCD, 0xFF),
-	_INIT_CMD(0x00, 0xCE, 0xFF),
-	_INIT_CMD(0x00, 0xB0, 0x0A),
-	_INIT_CMD(0x00, 0xB1, 0x00),
-	_INIT_CMD(0x00, 0xB2, 0x09),
-	_INIT_CMD(0x00, 0xB3, 0x19),
-	_INIT_CMD(0x00, 0xB4, 0x2F),
-	_INIT_CMD(0x00, 0xB5, 0x44),
-	_INIT_CMD(0x00, 0xB6, 0x52),
-	_INIT_CMD(0x00, 0xB7, 0x6A),
-	_INIT_CMD(0x00, 0xB8, 0x8A),
-	_INIT_CMD(0x00, 0xB9, 0xCA),
-	_INIT_CMD(0x00, 0xBA, 0x0C),
-	_INIT_CMD(0x00, 0xBB, 0x87),
-	_INIT_CMD(0x00, 0xBC, 0x06),
-	_INIT_CMD(0x00, 0xBD, 0x0A),
-	_INIT_CMD(0x00, 0xBE, 0x9B),
-	_INIT_CMD(0x00, 0xBF, 0x0C),
-	_INIT_CMD(0x00, 0xC0, 0x3D),
-	_INIT_CMD(0x00, 0xC1, 0x71),
-	_INIT_CMD(0x00, 0xC2, 0x90),
-	_INIT_CMD(0x00, 0xC3, 0xA0),
-	_INIT_CMD(0x00, 0xC4, 0xA8),
-	_INIT_CMD(0x00, 0xC5, 0xB1),
-	_INIT_CMD(0x00, 0xC6, 0xBB),
-	_INIT_CMD(0x00, 0xC7, 0xC0),
-	_INIT_CMD(0x00, 0xC8, 0xC4),
-	_INIT_CMD(0x00, 0xC9, 0x00),
-	_INIT_CMD(0x00, 0xCA, 0x00),
-	_INIT_CMD(0x00, 0xCB, 0x16),
-	_INIT_CMD(0x00, 0xCC, 0xAF),
-	_INIT_CMD(0x00, 0xCD, 0xFF),
-	_INIT_CMD(0x00, 0xCE, 0xFF),
-	_INIT_CMD(0x00, 0xB0, 0x0B),
-	_INIT_CMD(0x00, 0xB1, 0x04),
-	_INIT_CMD(0x00, 0xB2, 0x08),
-	_INIT_CMD(0x00, 0xB3, 0x19),
-	_INIT_CMD(0x00, 0xB4, 0x31),
-	_INIT_CMD(0x00, 0xB5, 0x46),
-	_INIT_CMD(0x00, 0xB6, 0x55),
-	_INIT_CMD(0x00, 0xB7, 0x6E),
-	_INIT_CMD(0x00, 0xB8, 0x92),
-	_INIT_CMD(0x00, 0xB9, 0xD4),
-	_INIT_CMD(0x00, 0xBA, 0x1B),
-	_INIT_CMD(0x00, 0xBB, 0x9B),
-	_INIT_CMD(0x00, 0xBC, 0x28),
-	_INIT_CMD(0x00, 0xBD, 0x2D),
-	_INIT_CMD(0x00, 0xBE, 0xC3),
-	_INIT_CMD(0x00, 0xBF, 0x2F),
-	_INIT_CMD(0x00, 0xC0, 0x62),
-	_INIT_CMD(0x00, 0xC1, 0x99),
-	_INIT_CMD(0x00, 0xC2, 0xAB),
-	_INIT_CMD(0x00, 0xC3, 0xBF),
-	_INIT_CMD(0x00, 0xC4, 0xCF),
-	_INIT_CMD(0x00, 0xC5, 0xDF),
-	_INIT_CMD(0x00, 0xC6, 0xF0),
-	_INIT_CMD(0x00, 0xC7, 0xF9),
-	_INIT_CMD(0x00, 0xC8, 0xFC),
-	_INIT_CMD(0x00, 0xC9, 0x00),
-	_INIT_CMD(0x00, 0xCA, 0x00),
-	_INIT_CMD(0x00, 0xCB, 0x16),
-	_INIT_CMD(0x00, 0xCC, 0xAF),
-	_INIT_CMD(0x00, 0xCD, 0xFF),
-	_INIT_CMD(0x00, 0xCE, 0xFF),
-	_INIT_CMD(0x00, 0xB0, 0x0C),
-	_INIT_CMD(0x00, 0xB1, 0x04),
-	_INIT_CMD(0x00, 0xB2, 0x05),
-	_INIT_CMD(0x00, 0xB3, 0x17),
-	_INIT_CMD(0x00, 0xB4, 0x2E),
-	_INIT_CMD(0x00, 0xB5, 0x42),
-	_INIT_CMD(0x00, 0xB6, 0x51),
-	_INIT_CMD(0x00, 0xB7, 0x69),
-	_INIT_CMD(0x00, 0xB8, 0x88),
-	_INIT_CMD(0x00, 0xB9, 0xC9),
-	_INIT_CMD(0x00, 0xBA, 0x0C),
-	_INIT_CMD(0x00, 0xBB, 0x86),
-	_INIT_CMD(0x00, 0xBC, 0x03),
-	_INIT_CMD(0x00, 0xBD, 0x08),
-	_INIT_CMD(0x00, 0xBE, 0x95),
-	_INIT_CMD(0x00, 0xBF, 0x05),
-	_INIT_CMD(0x00, 0xC0, 0x35),
-	_INIT_CMD(0x00, 0xC1, 0x62),
-	_INIT_CMD(0x00, 0xC2, 0x81),
-	_INIT_CMD(0x00, 0xC3, 0x96),
-	_INIT_CMD(0x00, 0xC4, 0x9E),
-	_INIT_CMD(0x00, 0xC5, 0xA5),
-	_INIT_CMD(0x00, 0xC6, 0xAD),
-	_INIT_CMD(0x00, 0xC7, 0xB1),
-	_INIT_CMD(0x00, 0xC8, 0xB4),
-	_INIT_CMD(0x00, 0xC9, 0x00),
-	_INIT_CMD(0x00, 0xCA, 0x00),
-	_INIT_CMD(0x00, 0xCB, 0x16),
-	_INIT_CMD(0x00, 0xCC, 0xAF),
-	_INIT_CMD(0x00, 0xCD, 0xFF),
-	_INIT_CMD(0x00, 0xCE, 0xFF),
-	_INIT_CMD(0x00, 0xB0, 0x00),
-	_INIT_CMD(0x00, 0xB3, 0x08),
-	_INIT_CMD(0x00, 0xB0, 0x04),
-	_INIT_CMD(0x64, 0xB8, 0x68),
+	_INIT_CMD(0xB0, 0x05),
+	_INIT_CMD(0xB1, 0xE5),
+	_INIT_CMD(0xB3, 0x52),
+	_INIT_CMD(0xB0, 0x00),
+	_INIT_CMD(0xB6, 0x03),
+	_INIT_CMD(0xBA, 0x8B),
+	_INIT_CMD(0xBF, 0x1A),
+	_INIT_CMD(0xC0, 0x0F),
+	_INIT_CMD(0xC2, 0x0C),
+	_INIT_CMD(0xC3, 0x02),
+	_INIT_CMD(0xC4, 0x0C),
+	_INIT_CMD(0xC5, 0x02),
+	_INIT_CMD(0xB0, 0x01),
+	_INIT_CMD(0xE0, 0x26),
+	_INIT_CMD(0xE1, 0x26),
+	_INIT_CMD(0xDC, 0x00),
+	_INIT_CMD(0xDD, 0x00),
+	_INIT_CMD(0xCC, 0x26),
+	_INIT_CMD(0xCD, 0x26),
+	_INIT_CMD(0xC8, 0x00),
+	_INIT_CMD(0xC9, 0x00),
+	_INIT_CMD(0xD2, 0x03),
+	_INIT_CMD(0xD3, 0x03),
+	_INIT_CMD(0xE6, 0x04),
+	_INIT_CMD(0xE7, 0x04),
+	_INIT_CMD(0xC4, 0x09),
+	_INIT_CMD(0xC5, 0x09),
+	_INIT_CMD(0xD8, 0x0A),
+	_INIT_CMD(0xD9, 0x0A),
+	_INIT_CMD(0xC2, 0x0B),
+	_INIT_CMD(0xC3, 0x0B),
+	_INIT_CMD(0xD6, 0x0C),
+	_INIT_CMD(0xD7, 0x0C),
+	_INIT_CMD(0xC0, 0x05),
+	_INIT_CMD(0xC1, 0x05),
+	_INIT_CMD(0xD4, 0x06),
+	_INIT_CMD(0xD5, 0x06),
+	_INIT_CMD(0xCA, 0x07),
+	_INIT_CMD(0xCB, 0x07),
+	_INIT_CMD(0xDE, 0x08),
+	_INIT_CMD(0xDF, 0x08),
+	_INIT_CMD(0xB0, 0x02),
+	_INIT_CMD(0xC0, 0x00),
+	_INIT_CMD(0xC1, 0x0D),
+	_INIT_CMD(0xC2, 0x17),
+	_INIT_CMD(0xC3, 0x26),
+	_INIT_CMD(0xC4, 0x31),
+	_INIT_CMD(0xC5, 0x1C),
+	_INIT_CMD(0xC6, 0x2C),
+	_INIT_CMD(0xC7, 0x33),
+	_INIT_CMD(0xC8, 0x31),
+	_INIT_CMD(0xC9, 0x37),
+	_INIT_CMD(0xCA, 0x37),
+	_INIT_CMD(0xCB, 0x37),
+	_INIT_CMD(0xCC, 0x39),
+	_INIT_CMD(0xCD, 0x2E),
+	_INIT_CMD(0xCE, 0x2F),
+	_INIT_CMD(0xCF, 0x2F),
+	_INIT_CMD(0xD0, 0x07),
+	_INIT_CMD(0xD2, 0x00),
+	_INIT_CMD(0xD3, 0x0D),
+	_INIT_CMD(0xD4, 0x17),
+	_INIT_CMD(0xD5, 0x26),
+	_INIT_CMD(0xD6, 0x31),
+	_INIT_CMD(0xD7, 0x3F),
+	_INIT_CMD(0xD8, 0x3F),
+	_INIT_CMD(0xD9, 0x3F),
+	_INIT_CMD(0xDA, 0x3F),
+	_INIT_CMD(0xDB, 0x37),
+	_INIT_CMD(0xDC, 0x37),
+	_INIT_CMD(0xDD, 0x37),
+	_INIT_CMD(0xDE, 0x39),
+	_INIT_CMD(0xDF, 0x2E),
+	_INIT_CMD(0xE0, 0x2F),
+	_INIT_CMD(0xE1, 0x2F),
+	_INIT_CMD(0xE2, 0x07),
+	_INIT_CMD(0xB0, 0x03),
+	_INIT_CMD(0xC8, 0x0B),
+	_INIT_CMD(0xC9, 0x07),
+	_INIT_CMD(0xC3, 0x00),
+	_INIT_CMD(0xE7, 0x00),
+	_INIT_CMD(0xC5, 0x2A),
+	_INIT_CMD(0xDE, 0x2A),
+	_INIT_CMD(0xCA, 0x43),
+	_INIT_CMD(0xC9, 0x07),
+	_INIT_CMD(0xE4, 0xC0),
+	_INIT_CMD(0xE5, 0x0D),
+	_INIT_CMD(0xCB, 0x01),
+	_INIT_CMD(0xBC, 0x01),
+	_INIT_CMD(0xB0, 0x06),
+	_INIT_CMD(0xB8, 0xA5),
+	_INIT_CMD(0xC0, 0xA5),
+	_INIT_CMD(0xC7, 0x0F),
+	_INIT_CMD(0xD5, 0x32),
+	_INIT_CMD(0xB8, 0x00),
+	_INIT_CMD(0xC0, 0x00),
+	_INIT_CMD(0xBC, 0x00),
+	_INIT_CMD(0xB0, 0x07),
+	_INIT_CMD(0xB1, 0x00),
+	_INIT_CMD(0xB2, 0x05),
+	_INIT_CMD(0xB3, 0x10),
+	_INIT_CMD(0xB4, 0x22),
+	_INIT_CMD(0xB5, 0x36),
+	_INIT_CMD(0xB6, 0x4A),
+	_INIT_CMD(0xB7, 0x6C),
+	_INIT_CMD(0xB8, 0x9A),
+	_INIT_CMD(0xB9, 0xD7),
+	_INIT_CMD(0xBA, 0x17),
+	_INIT_CMD(0xBB, 0x92),
+	_INIT_CMD(0xBC, 0x15),
+	_INIT_CMD(0xBD, 0x18),
+	_INIT_CMD(0xBE, 0x8C),
+	_INIT_CMD(0xBF, 0x00),
+	_INIT_CMD(0xC0, 0x3A),
+	_INIT_CMD(0xC1, 0x72),
+	_INIT_CMD(0xC2, 0x8C),
+	_INIT_CMD(0xC3, 0xA5),
+	_INIT_CMD(0xC4, 0xB1),
+	_INIT_CMD(0xC5, 0xBE),
+	_INIT_CMD(0xC6, 0xCA),
+	_INIT_CMD(0xC7, 0xD1),
+	_INIT_CMD(0xC8, 0xD4),
+	_INIT_CMD(0xC9, 0x00),
+	_INIT_CMD(0xCA, 0x00),
+	_INIT_CMD(0xCB, 0x16),
+	_INIT_CMD(0xCC, 0xAF),
+	_INIT_CMD(0xCD, 0xFF),
+	_INIT_CMD(0xCE, 0xFF),
+	_INIT_CMD(0xB0, 0x08),
+	_INIT_CMD(0xB1, 0x04),
+	_INIT_CMD(0xB2, 0x05),
+	_INIT_CMD(0xB3, 0x11),
+	_INIT_CMD(0xB4, 0x24),
+	_INIT_CMD(0xB5, 0x39),
+	_INIT_CMD(0xB6, 0x4E),
+	_INIT_CMD(0xB7, 0x72),
+	_INIT_CMD(0xB8, 0xA3),
+	_INIT_CMD(0xB9, 0xE1),
+	_INIT_CMD(0xBA, 0x25),
+	_INIT_CMD(0xBB, 0xA8),
+	_INIT_CMD(0xBC, 0x2E),
+	_INIT_CMD(0xBD, 0x32),
+	_INIT_CMD(0xBE, 0xAD),
+	_INIT_CMD(0xBF, 0x28),
+	_INIT_CMD(0xC0, 0x63),
+	_INIT_CMD(0xC1, 0x9B),
+	_INIT_CMD(0xC2, 0xB5),
+	_INIT_CMD(0xC3, 0xCF),
+	_INIT_CMD(0xC4, 0xDB),
+	_INIT_CMD(0xC5, 0xE8),
+	_INIT_CMD(0xC6, 0xF5),
+	_INIT_CMD(0xC7, 0xFA),
+	_INIT_CMD(0xC8, 0xFC),
+	_INIT_CMD(0xC9, 0x00),
+	_INIT_CMD(0xCA, 0x00),
+	_INIT_CMD(0xCB, 0x16),
+	_INIT_CMD(0xCC, 0xAF),
+	_INIT_CMD(0xCD, 0xFF),
+	_INIT_CMD(0xCE, 0xFF),
+	_INIT_CMD(0xB0, 0x09),
+	_INIT_CMD(0xB1, 0x04),
+	_INIT_CMD(0xB2, 0x04),
+	_INIT_CMD(0xB3, 0x0F),
+	_INIT_CMD(0xB4, 0x22),
+	_INIT_CMD(0xB5, 0x37),
+	_INIT_CMD(0xB6, 0x4D),
+	_INIT_CMD(0xB7, 0x71),
+	_INIT_CMD(0xB8, 0xA2),
+	_INIT_CMD(0xB9, 0xE1),
+	_INIT_CMD(0xBA, 0x26),
+	_INIT_CMD(0xBB, 0xA9),
+	_INIT_CMD(0xBC, 0x2F),
+	_INIT_CMD(0xBD, 0x33),
+	_INIT_CMD(0xBE, 0xAC),
+	_INIT_CMD(0xBF, 0x24),
+	_INIT_CMD(0xC0, 0x5D),
+	_INIT_CMD(0xC1, 0x94),
+	_INIT_CMD(0xC2, 0xAC),
+	_INIT_CMD(0xC3, 0xC5),
+	_INIT_CMD(0xC4, 0xD1),
+	_INIT_CMD(0xC5, 0xDC),
+	_INIT_CMD(0xC6, 0xE8),
+	_INIT_CMD(0xC7, 0xED),
+	_INIT_CMD(0xC8, 0xF0),
+	_INIT_CMD(0xC9, 0x00),
+	_INIT_CMD(0xCA, 0x00),
+	_INIT_CMD(0xCB, 0x16),
+	_INIT_CMD(0xCC, 0xAF),
+	_INIT_CMD(0xCD, 0xFF),
+	_INIT_CMD(0xCE, 0xFF),
+	_INIT_CMD(0xB0, 0x0A),
+	_INIT_CMD(0xB1, 0x00),
+	_INIT_CMD(0xB2, 0x05),
+	_INIT_CMD(0xB3, 0x10),
+	_INIT_CMD(0xB4, 0x22),
+	_INIT_CMD(0xB5, 0x36),
+	_INIT_CMD(0xB6, 0x4A),
+	_INIT_CMD(0xB7, 0x6C),
+	_INIT_CMD(0xB8, 0x9A),
+	_INIT_CMD(0xB9, 0xD7),
+	_INIT_CMD(0xBA, 0x17),
+	_INIT_CMD(0xBB, 0x92),
+	_INIT_CMD(0xBC, 0x15),
+	_INIT_CMD(0xBD, 0x18),
+	_INIT_CMD(0xBE, 0x8C),
+	_INIT_CMD(0xBF, 0x00),
+	_INIT_CMD(0xC0, 0x3A),
+	_INIT_CMD(0xC1, 0x72),
+	_INIT_CMD(0xC2, 0x8C),
+	_INIT_CMD(0xC3, 0xA5),
+	_INIT_CMD(0xC4, 0xB1),
+	_INIT_CMD(0xC5, 0xBE),
+	_INIT_CMD(0xC6, 0xCA),
+	_INIT_CMD(0xC7, 0xD1),
+	_INIT_CMD(0xC8, 0xD4),
+	_INIT_CMD(0xC9, 0x00),
+	_INIT_CMD(0xCA, 0x00),
+	_INIT_CMD(0xCB, 0x16),
+	_INIT_CMD(0xCC, 0xAF),
+	_INIT_CMD(0xCD, 0xFF),
+	_INIT_CMD(0xCE, 0xFF),
+	_INIT_CMD(0xB0, 0x0B),
+	_INIT_CMD(0xB1, 0x04),
+	_INIT_CMD(0xB2, 0x05),
+	_INIT_CMD(0xB3, 0x11),
+	_INIT_CMD(0xB4, 0x24),
+	_INIT_CMD(0xB5, 0x39),
+	_INIT_CMD(0xB6, 0x4E),
+	_INIT_CMD(0xB7, 0x72),
+	_INIT_CMD(0xB8, 0xA3),
+	_INIT_CMD(0xB9, 0xE1),
+	_INIT_CMD(0xBA, 0x25),
+	_INIT_CMD(0xBB, 0xA8),
+	_INIT_CMD(0xBC, 0x2E),
+	_INIT_CMD(0xBD, 0x32),
+	_INIT_CMD(0xBE, 0xAD),
+	_INIT_CMD(0xBF, 0x28),
+	_INIT_CMD(0xC0, 0x63),
+	_INIT_CMD(0xC1, 0x9B),
+	_INIT_CMD(0xC2, 0xB5),
+	_INIT_CMD(0xC3, 0xCF),
+	_INIT_CMD(0xC4, 0xDB),
+	_INIT_CMD(0xC5, 0xE8),
+	_INIT_CMD(0xC6, 0xF5),
+	_INIT_CMD(0xC7, 0xFA),
+	_INIT_CMD(0xC8, 0xFC),
+	_INIT_CMD(0xC9, 0x00),
+	_INIT_CMD(0xCA, 0x00),
+	_INIT_CMD(0xCB, 0x16),
+	_INIT_CMD(0xCC, 0xAF),
+	_INIT_CMD(0xCD, 0xFF),
+	_INIT_CMD(0xCE, 0xFF),
+	_INIT_CMD(0xB0, 0x0C),
+	_INIT_CMD(0xB1, 0x04),
+	_INIT_CMD(0xB2, 0x04),
+	_INIT_CMD(0xB3, 0x0F),
+	_INIT_CMD(0xB4, 0x22),
+	_INIT_CMD(0xB5, 0x37),
+	_INIT_CMD(0xB6, 0x4D),
+	_INIT_CMD(0xB7, 0x71),
+	_INIT_CMD(0xB8, 0xA2),
+	_INIT_CMD(0xB9, 0xE1),
+	_INIT_CMD(0xBA, 0x26),
+	_INIT_CMD(0xBB, 0xA9),
+	_INIT_CMD(0xBC, 0x2F),
+	_INIT_CMD(0xBD, 0x33),
+	_INIT_CMD(0xBE, 0xAC),
+	_INIT_CMD(0xBF, 0x24),
+	_INIT_CMD(0xC0, 0x5D),
+	_INIT_CMD(0xC1, 0x94),
+	_INIT_CMD(0xC2, 0xAC),
+	_INIT_CMD(0xC3, 0xC5),
+	_INIT_CMD(0xC4, 0xD1),
+	_INIT_CMD(0xC5, 0xDC),
+	_INIT_CMD(0xC6, 0xE8),
+	_INIT_CMD(0xC7, 0xED),
+	_INIT_CMD(0xC8, 0xF0),
+	_INIT_CMD(0xC9, 0x00),
+	_INIT_CMD(0xCA, 0x00),
+	_INIT_CMD(0xCB, 0x16),
+	_INIT_CMD(0xCC, 0xAF),
+	_INIT_CMD(0xCD, 0xFF),
+	_INIT_CMD(0xCE, 0xFF),
 
 	{},
 };
@@ -896,17 +843,11 @@ static const struct panel_desc boe_himax8279d10p_panel_desc = {
 	.bpc = 8,
 	.width_mm = 135,
 	.height_mm = 216,
-	.delay_t1 = 5000,
-	.reset_delay_t2 = 14000,
-	.reset_delay_t3 = 1000,
-	.reset_delay_t4 = 1000,
-	.reset_delay_t5 = 5000,
 	.mode_flags = MIPI_DSI_MODE_VIDEO | MIPI_DSI_MODE_VIDEO_SYNC_PULSE |
 			MIPI_DSI_CLOCK_NON_CONTINUOUS | MIPI_DSI_MODE_LPM,
 	.format = MIPI_DSI_FMT_RGB888,
 	.lanes = 4,
 	.on_cmds = boe_himax8279d10p_on_cmds,
-	.off_cmds = default_off_cmds,
 };
 
 static const struct of_device_id panel_of_match[] = {
-- 
2.17.1

